@@ -1,23 +1,18 @@
-#!/bin/false
+package Catalyst::Helper::View::TT::Alloy;
 
 use strict;
-package Catalyst::Helper::View::TT::Alloy;
-$Catalyst::Helper::View::TT::Alloy::VERSION = '0.00005_01';
+
 =head1 NAME
 
-Catalyst::Helper::View::TT::Alloy - Helper for Template::Alloy Views
-
-=head1 VERSION
-
-version 0.00005_01
+Catalyst::Helper::View::TT - Helper for TT Views
 
 =head1 SYNOPSIS
 
-    script/create.pl view TT::Alloy TT::Alloy
+    script/create.pl view TT TT
 
 =head1 DESCRIPTION
 
-Helper for Template::Alloy Views.
+Helper for TT Views.
 
 =head2 METHODS
 
@@ -33,16 +28,12 @@ sub mk_compclass {
 
 =head1 SEE ALSO
 
-L<Catalyst::View::TT::Alloy>, L<Template::Alloy>, L<Catalyst::Manual>
+L<Catalyst::Manual>, L<Catalyst::Test>, L<Catalyst::Request>,
+L<Catalyst::Response>, L<Catalyst::Helper>
 
-=head1 AUTHORS
-
-Carl Franks, C<cfranks@cpan.org>
-
-Based on the code of C<Catalyst::Helper::TT::Alloy>, by
+=head1 AUTHOR
 
 Sebastian Riedel, C<sri@oook.de>
-
 Marcus Ramberg, C<mramberg@cpan.org>
 
 =head1 LICENSE
@@ -60,7 +51,7 @@ __compclass__
 package [% class %];
 
 use strict;
-use parent 'Catalyst::View::TT::Alloy';
+use base 'Catalyst::View::TT::Alloy';
 
 1;
 
@@ -72,7 +63,7 @@ __END__
 
 =head1 DESCRIPTION
 
-TT::Alloy View for [% app %].
+TT::Alloy View for [% app %]. 
 
 =head1 AUTHOR
 
